<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Http\Controllers\Coach;
use Illuminate\Http\Request;
use App\Http\Helper\Helper;
use App\Validators\Admin\AdminDecisionValidator;
use Illuminate\Support\Facades\Hash;
use App\Managers\Decision\DecisionManager;
use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;

class DecisionController extends Controller
{
    public function __construct()
    {
        $this->helper = new Helper();
        $this->decisionValidator = new AdminDecisionValidator();
        $this->decisionManager = new DecisionManager();
    }
    
    public function add()
    {
        return view('/admin/decision/add');
    }
    
    public function save(Request $request)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'create');
        
        $validation = $this->decisionValidator->add($data);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->decisionManager->add($data);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Decision Saved Successfully'], 200);
    }
    
    public function index()
    {
        $decisions = $this->decisionManager->with('user')->get();
        return view('/admin/decision/list')->with('decisions', $decisions);
    }
    
    public function edit($UUID)
    {
        return view('/admin/decision/edit')->with('UUID', $UUID);
    }
    
    public function currentDecisionProposal($UUID)
    {
        $decision = $this->decisionManager->where('UUID', $UUID)->first()->toArray();
        return response()->json($decision,200);
    }
    
    public function update(Request $request, $UUID)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'update');
        
        $validation = $this->decisionValidator->update($data, $UUID);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->decisionManager->updateData($data, $UUID);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Decision Updated Successfully'], 200);
    }
    
    public function confirmProposal(Request $request)
    {
        if(!$request->exists('id'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $id = $request->get('id');
        $confirm = $this->decisionManager->confirmProposal($id);
        if(!$confirm)
        {
             return response()->json(['Something went wrong'], 500);
        }
        return response()->json(['Proposal Confrimed'], 200);
    }
    
    public function denyProposal(Request $request)
    {
        if(!$request->exists('id'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $id = $request->get('id');
        $confirm = $this->decisionManager->denyProposal($id);
        if(!$confirm)
        {
             return response()->json(['Something went wrong'], 500);
        }
        return response()->json(['Proposal Confrimed'], 200);
    }
}